@@ -5,6 +5,7 @@ if (sys.version_info[0] == 2 and sys.version_info[:2] >= (2,7)) or \
 else:
     import unittest2 as unittest
 
+import platform
 import subprocess
 import shutil
 import time
@@ -12,10 +13,8 @@ import os
 import signal
 import py2app
 import hashlib
-if __name__ == "__main__":
-    from tools import kill_child_processes
-else:
-    from .tools import kill_child_processes
+import sysconfig
+from .tools import kill_child_processes
 
 DIR_NAME=os.path.dirname(os.path.abspath(__file__))
 
@@ -66,6 +65,20 @@ class TestBasicAppWithPlugins (unittest.TestCase):
             # Ensure that testing though SSH works
             env['LANG'] = 'en_US.UTF-8'
 
+        p = subprocess.Popen([
+                sys.executable ] + cls.python_args + [
+                    'setup.py', 'pluginexe'],
+            cwd = cls.app_dir,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            close_fds=False,
+            env=env
+            )
+        lines = p.communicate()[0]
+        if p.wait() != 0:
+            print (lines)
+            raise AssertionError("Creating plugin executable failed")
+
         p = subprocess.Popen([
                 sys.executable ] + cls.python_args + [
                     'setup.py', 'py2app'] + cls.py2app_args,
@@ -96,6 +109,19 @@ class TestBasicAppWithPlugins (unittest.TestCase):
         if os.path.exists(os.path.join(cls.app_dir, 'dist')):
             shutil.rmtree(os.path.join(cls.app_dir, 'dist'))
 
+        p = subprocess.Popen([
+                sys.executable ] + cls.python_args + [
+                    'setup.py', 'cleanup'],
+            cwd = cls.app_dir,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            close_fds=False,
+            )
+        lines = p.communicate()[0]
+        if p.wait() != 0:
+            print (lines)
+            raise AssertionError("Cleanup failed")
+
         time.sleep(2)
 
     def tearDown(self):
